#[repr(u8)]pub enum ZoneEventStoppedReason {
Actionstopped = 0,
Timeout = 1,
}Variants
Actionstopped = 0
Indicates that whatever triggered the Zone event has stopped being detected.
Timeout = 1
Indicates that the max duration for detecting triggering activity has been reached.
Implementations